==> ejc-bidprice-impl-3.0.0-20230217.100019-66-sources.jar: com/ejianc/business/bidprice/material/service/impl/MaterialInquiryServiceImpl.java <==
package com.ejianc.business.bidprice.material.service.impl;

import com.baomidou.mybatisplus.core.conditions.update.LambdaUpdateWrapper;
import com.ejianc.business.bidprice.consts.InquiryStateEnum;
import com.ejianc.business.bidprice.material.vo.MaterialInquiryPurchaseDetailVO;
import com.ejianc.business.bidprice.material.vo.MaterialInquiryVO;
import com.ejianc.business.material.api.IMaterialSettlementApi;
import com.ejianc.business.material.vo.MaterialPriceVO;
import com.ejianc.framework.core.context.InvocationInfoProxy;
import com.ejianc.framework.core.response.CommonResponse;
import org.apache.commons.collections.CollectionUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ejianc.framework.skeleton.template.BaseServiceImpl;

import com.ejianc.business.bidprice.material.mapper.MaterialInquiryMapper;
import com.ejianc.business.bidprice.material.bean.MaterialInquiryEntity;
import com.ejianc.business.bidprice.material.service.IMaterialInquiryService;

import java.math.BigDecimal;
import java.util.ArrayList;
import java.util.Date;
import java.util.List;
import java.util.Map;
import java.util.stream.Collectors;

/**
 * 材料询价
 * 
 * @author generator
 * 
 */
@Service("materialInquiryService")
public class MaterialInquiryServiceImpl extends BaseServiceImpl<MaterialInquiryMapper, MaterialInquiryEntity> implements IMaterialInquiryService{

    @Autowired
    private MaterialInquiryMapper materialInquiryMapper;

    @Autowired
    private IMaterialSettlementApi materialSettlementApi;

    @Override
    public MaterialInquiryVO updateInquiry(MaterialInquiryVO updateVo) {
        Long id = updateVo.getId();
        Date quoteEndDate = updateVo.getQuoteEndDate();
        //是否截止标志
        Boolean quoteEndFlag = updateVo.getQuoteEndFlag();
        MaterialInquiryEntity entity = super.selectById(id);
        if(entity != null){
            LambdaUpdateWrapper<MaterialInquiryEntity> updateWrapper = new LambdaUpdateWrapper<>();
            updateWrapper.eq(MaterialInquiryEntity::getId,id);
            updateWrapper.set(MaterialInquiryEntity::getQuoteEndDate,quoteEndDate);
            //如果截止，修改询价状态为已截止
            if(quoteEndFlag){
                updateWrapper.set(MaterialInquiryEntity::getInquiryState, InquiryStateEnum.EXPIRATION_STATE.getCode());
            }
            super.update(updateWrapper);
        }
        return updateVo;
    }


    /**
     * 计算历史价接口，查询明细，保存返回时使用
     * @param vo
     * @return
     */
    @Override
    public MaterialInquiryVO queryMaterialPrice(MaterialInquiryVO vo) {
        List<MaterialInquiryPurchaseDetailVO> purchaseDetailList = vo.getMaterialInquiryPurchaseDetailList();
        if (CollectionUtils.isNotEmpty(purchaseDetailList)) {
            MaterialPriceVO priceVO = new MaterialPriceVO();
            List<MaterialPriceVO> detail = new ArrayList<>();
            purchaseDetailList.forEach(item -> {
                MaterialPriceVO materialPriceVO = new MaterialPriceVO();
                materialPriceVO.setMaterialId(Long.valueOf(item.getMaterialId()));
                detail.add(materialPriceVO);
            });
            priceVO.setDetail(detail);
            CommonResponse<MaterialPriceVO> commonResponse = materialSettlementApi.queryPrice(priceVO);
            if(commonResponse.isSuccess()){
                MaterialPriceVO materialPriceVO = commonResponse.getData();
                List<MaterialPriceVO> dd = materialPriceVO.getDetail();
                if (CollectionUtils.isNotEmpty(dd)) {
                    Map<Long, MaterialPriceVO> priceVOMap = dd.stream().collect(Collectors.toMap(MaterialPriceVO::getMaterialId, account -> account,(v1, v2) -> v2));
                    for (MaterialInquiryPurchaseDetailVO v : vo.getMaterialInquiryPurchaseDetailList()) {
                        Long materialId = v.getMaterialId();
                        MaterialPriceVO p = priceVOMap.get(materialId);
                        if (null != p) {
                            v.setMinPrice(p.getMinPrice());
                            v.setMaxPrice(p.getMaxPrice());
                            v.setPriceArea(p.getMinPrice().setScale(2,BigDecimal.ROUND_HALF_UP) + "~" + p.getMaxPrice().setScale(2,BigDecimal.ROUND_HALF_UP));
                        }
                    }
                }
            }
        }
        return vo;
    }


    @Override
    public void updateInquiry(Long inquiryId,Integer inquiryState){
        LambdaUpdateWrapper<MaterialInquiryEntity> updateWrapper = new LambdaUpdateWrapper<>();
        updateWrapper.eq(MaterialInquiryEntity::getId,inquiryId);
        updateWrapper.set(MaterialInquiryEntity::getInquiryState, inquiryState);
        super.update(updateWrapper);
    }

}

==> ejc-bidprice-impl-3.0.0-20230221.025936-78-sources.jar: com/ejianc/business/bidprice/material/service/impl/MaterialInquiryServiceImpl.java <==
package com.ejianc.business.bidprice.material.service.impl;

import com.baomidou.mybatisplus.core.conditions.update.LambdaUpdateWrapper;
import com.ejianc.business.bidprice.consts.InquiryStateEnum;
import com.ejianc.business.bidprice.material.vo.MaterialInquiryPurchaseDetailVO;
import com.ejianc.business.bidprice.material.vo.MaterialInquiryVO;
import com.ejianc.business.material.api.IMaterialSettlementApi;
import com.ejianc.business.material.vo.MaterialPriceVO;
import com.ejianc.framework.core.context.InvocationInfoProxy;
import com.ejianc.framework.core.response.CommonResponse;
import org.apache.commons.collections.CollectionUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ejianc.framework.skeleton.template.BaseServiceImpl;

import com.ejianc.business.bidprice.material.mapper.MaterialInquiryMapper;
import com.ejianc.business.bidprice.material.bean.MaterialInquiryEntity;
import com.ejianc.business.bidprice.material.service.IMaterialInquiryService;

import java.math.BigDecimal;
import java.util.ArrayList;
import java.util.Date;
import java.util.List;
import java.util.Map;
import java.util.stream.Collectors;

/**
 * 材料询价
 * 
 * @author generator
 * 
 */
@Service("materialInquiryService")
public class MaterialInquiryServiceImpl extends BaseServiceImpl<MaterialInquiryMapper, MaterialInquiryEntity> implements IMaterialInquiryService{

    @Autowired
    private MaterialInquiryMapper materialInquiryMapper;

    @Autowired
    private IMaterialSettlementApi materialSettlementApi;

    @Override
    public MaterialInquiryVO updateInquiry(MaterialInquiryVO updateVo) {
        Long id = updateVo.getId();
        Date quoteEndDate = updateVo.getQuoteEndDate();
        //是否截止标志
        Boolean quoteEndFlag = updateVo.getQuoteEndFlag();
        MaterialInquiryEntity entity = super.selectById(id);
        if(entity != null){
            LambdaUpdateWrapper<MaterialInquiryEntity> updateWrapper = new LambdaUpdateWrapper<>();
            updateWrapper.eq(MaterialInquiryEntity::getId,id);
            updateWrapper.set(MaterialInquiryEntity::getQuoteEndDate,quoteEndDate);
            //如果截止，修改询价状态为已截止
            if(quoteEndFlag){
                updateWrapper.set(MaterialInquiryEntity::getInquiryState, InquiryStateEnum.EXPIRATION_STATE.getCode());
            }
            //如果已截止，但截止时间大于当前时间，修改询价状态为报价中
            if(InquiryStateEnum.EXPIRATION_STATE.getCode().equals(entity.getInquiryState()) && quoteEndDate.compareTo(new Date()) > 0){
                updateWrapper.set(MaterialInquiryEntity::getInquiryState, InquiryStateEnum.QUOTATION_STATE.getCode());
            }
            super.update(updateWrapper);
        }
        return updateVo;
    }


    /**
     * 计算历史价接口，查询明细，保存返回时使用
     * @param vo
     * @return
     */
    @Override
    public MaterialInquiryVO queryMaterialPrice(MaterialInquiryVO vo) {
        List<MaterialInquiryPurchaseDetailVO> purchaseDetailList = vo.getMaterialInquiryPurchaseDetailList();
        if (CollectionUtils.isNotEmpty(purchaseDetailList)) {
            MaterialPriceVO priceVO = new MaterialPriceVO();
            List<MaterialPriceVO> detail = new ArrayList<>();
            purchaseDetailList.forEach(item -> {
                MaterialPriceVO materialPriceVO = new MaterialPriceVO();
                materialPriceVO.setMaterialId(Long.valueOf(item.getMaterialId()));
                detail.add(materialPriceVO);
            });
            priceVO.setDetail(detail);
            CommonResponse<MaterialPriceVO> commonResponse = materialSettlementApi.queryPrice(priceVO);
            if(commonResponse.isSuccess()){
                MaterialPriceVO materialPriceVO = commonResponse.getData();
                List<MaterialPriceVO> dd = materialPriceVO.getDetail();
                if (CollectionUtils.isNotEmpty(dd)) {
                    Map<Long, MaterialPriceVO> priceVOMap = dd.stream().collect(Collectors.toMap(MaterialPriceVO::getMaterialId, account -> account,(v1, v2) -> v2));
                    for (MaterialInquiryPurchaseDetailVO v : vo.getMaterialInquiryPurchaseDetailList()) {
                        Long materialId = v.getMaterialId();
                        MaterialPriceVO p = priceVOMap.get(materialId);
                        if (null != p) {
                            v.setMinPrice(p.getMinPrice());
                            v.setMaxPrice(p.getMaxPrice());
                            v.setPriceArea(p.getMinPrice().setScale(2,BigDecimal.ROUND_HALF_UP) + "~" + p.getMaxPrice().setScale(2,BigDecimal.ROUND_HALF_UP));
                        }
                    }
                }
            }
        }
        return vo;
    }


    @Override
    public void updateInquiry(Long inquiryId,Integer inquiryState){
        LambdaUpdateWrapper<MaterialInquiryEntity> updateWrapper = new LambdaUpdateWrapper<>();
        updateWrapper.eq(MaterialInquiryEntity::getId,inquiryId);
        updateWrapper.set(MaterialInquiryEntity::getInquiryState, inquiryState);
        super.update(updateWrapper);
    }

}
